from setuptools import find_packages, setup
setup(
    name='aguantest',
    version='1.0.0',
    description='a automated test tools',
    author='szmgithubcode',
    author_email='13023297816@163.com',
    url='https://github.com/szmgithubcode/',
    packages=['aguantest'],
)
